@@ -160,6 +160,8 @@ from .functions import (
     once,
     partial,
     partial_right,
+    pipe,
+    pipe_right,
     throttle,
     wrap,
 )
@@ -347,3 +349,4 @@ from .exceptions import (
 #
 
 _ = _Dash()
+py_ = _
